@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">Makrooj kaj programado</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">Macros and Scripting</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
     <li><a target="_top" href="eo/text/sbasic/shared/main0601.html">Helpo de LibreOffice Basic</a></li>\
     <li><a target="_top" href="eo/text/sbasic/shared/01000000.html">Programming with LibreOffice Basic</a></li>\
@@ -124,6 +124,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
     <li><a target="_top" href="eo/text/sbasic/shared/03120301.html">Format Function</a></li>\
     <li><a target="_top" href="eo/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
+    <li><a target="_top" href="eo/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
     <li><a target="_top" href="eo/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
     <li><a target="_top" href="eo/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
     <li><a target="_top" href="eo/text/sbasic/shared/03090406.html">Function Statement</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">Kalkultabeloj</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">Spreadsheets (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
     <li><a target="_top" href="eo/text/scalc/main0000.html">Bonvenon al la Helpo de LibreOffice Tabelilo</a></li>\
     <li><a target="_top" href="eo/text/scalc/main0503.html">Ebloj de LibreOffice Tabelilo</a></li>\
@@ -477,7 +478,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/schart/04/01020000.html">Fulmoklavoj por Diagramoj</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">Instalado</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice Installation</label><ul>\
     <li><a target="_top" href="eo/text/shared/guide/ms_doctypes.html">Ŝanĝi la asocion de tipoj de Microsoft Office-dokumentoj</a></li>\
     <li><a target="_top" href="eo/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/shared/optionen/01010200.html">Ĝenerala</a></li>\
     <li><a target="_top" href="eo/text/shared/optionen/01010300.html">Vojprefiksoj</a></li>\
     <li><a target="_top" href="eo/text/shared/optionen/01010400.html">Skribhelpoj</a></li>\
-    <li><a target="_top" href="eo/text/shared/optionen/01010500.html">Color</a></li>\
     <li><a target="_top" href="eo/text/shared/optionen/01010600.html">Ĝenerala</a></li>\
     <li><a target="_top" href="eo/text/shared/optionen/01010700.html">Tiparoj</a></li>\
     <li><a target="_top" href="eo/text/shared/optionen/01010800.html">Vido</a></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/shared/guide/numbering_stop.html">Turning off Bullets and Numbering for Individual Paragraphs</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">Datumbaza funkciado</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">Database Functionality (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">Ĝenerala informo</label><ul>\
     <li><a target="_top" href="eo/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
     <li><a target="_top" href="eo/text/shared/guide/database_main.html">Database Overview</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">Prezentaĵoj kaj desegnaĵoj</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">Presentations and Drawings (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
     <li><a target="_top" href="eo/text/simpress/main0000.html">Bonvenon al la helpo de LibreOffice-Prezentilo</a></li>\
     <li><a target="_top" href="eo/text/sdraw/main0000.html">Bonvenon al la helpo de LibreOffice-Desegnilo</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/simpress/guide/rehearse_timings.html">Rehearse Timings of Slide Changes</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">Formuloj</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">Formulas (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
     <li><a target="_top" href="eo/text/smath/main0000.html">Bonvenon al la Helpo de LibreOffice-Formulilo</a></li>\
     <li><a target="_top" href="eo/text/smath/main0503.html">Ebloj de LibreOffice-Formulilo</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/smath/guide/parentheses.html">Inserting Brackets</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">Tekstaj dokumentoj</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">Text Documents (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">Ĝenerala informo kaj uzado de uzinterfaco</label><ul>\
     <li><a target="_top" href="eo/text/swriter/main0000.html">Bonvenon al la helpo de LibreOffice-Verkilo</a></li>\
     <li><a target="_top" href="eo/text/swriter/main0503.html">Ebloj de LibreOffice Verkilo</a></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="eo/text/shared/01/02100001.html">List of Regular Expressions</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">HTML-dokumentoj</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML Documents (Writer Web)</label><ul>\
     <li><a target="_top" href="eo/text/shared/07/09000000.html">TTT-paĝoj</a></li>\
     <li><a target="_top" href="eo/text/shared/02/01170700.html">HTML Filters and Forms</a></li>\
     <li><a target="_top" href="eo/text/swriter/guide/send2html.html">Konservi tekstajn dokumentojn en HTML-formato</a></li>\
